# Frontdoor

> see https://aka.ms/autorest

This is the AutoRest configuration file for Network.



---
## Getting Started
To build the SDK for FrontDoor, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the FrontDoor API.

``` yaml
title: FrontDoorManagementClient
description: FrontDoor Client
openapi-type: arm
tag: package-2018-08-preview
```

### Tag: package-2018-08-preview

These settings apply only when `--tag=package-2018-08-preview` is specified on the command line.

``` yaml $(tag) == 'package-2018-08-preview'
input-file:
- Microsoft.Network/preview/2018-08-01-preview/frontdoor.json
- Microsoft.Network/preview/2018-08-01-preview/network.json
- Microsoft.Network/preview/2018-08-01-preview/webapplicationfirewall.json
directive:
  - where:
      - $.paths
    suppress:
      - OperationsAPIImplementation
```

---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-libraries-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.FrontDoor
  output-folder: $(csharp-sdks-folder)/FrontDoor/Management.FrontDoor/Generated
  clear-output-folder: true
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  fluent: true
  namespace: com.microsoft.azure.management.frontdoor
  license-header: MICROSOFT_MIT_NO_CODEGEN
  payload-flattening-threshold: 1
  output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-frontdoor
```

# Validation Suppressions

``` yaml $(azure-validator)
directive:
  - from: frontdoor.json
    where: [$.paths]
    suppress: OperationsAPIImplementation
    reason: Networking resource operations defined elsewhere.
  - from: frontdoor.json
    where: [$.definitions.Frontdoor,$.definitions.RoutingRule,$.definitions.FrontendEndpoint,$.definitions.BackendPool,$.definitions.LoadBalancingSettingsModel,$.definitions.HealthProbeSettingsModel]
    suppress: RequiredPropertiesMissingInResourceModel
    reason: Networking resource id is not readonly.
  - from: frontdoor.json
    where: [$.definitions.ValidateCustomDomainOutput.properties.customDomainValidated]
    suppress: EnumInsteadOfBoolean
    reason: Direct copy of ValidateCustomDomain API in CDN Resource Provider.
```
